@@ -3,10 +3,12 @@
 Enumerating stereoisomers for each SMILES representation with RDKit.
 """
 import warnings
+import shutil
 import os
 import glob
 import collections
 from openbabel import pybel
+from send2trash import send2trash
 from rdkit import Chem
 from rdkit.Chem import AllChem
 from rdkit.Chem.EnumerateStereoisomers import EnumerateStereoisomers
@@ -153,10 +155,19 @@ class rd_isomer(object):
     def conformer_func(self, smi_name):
         """smi_name is a tuple (smiles, name)"""
         smi, name = smi_name
+        mol = Chem.MolFromSmiles(smi)
+        atom_list = [atom.GetAtomicNum() for atom in mol.GetAtoms()]
+        num_atoms = len(atom_list)
         mol = Chem.AddHs(Chem.MolFromSmiles(smi))
-        AllChem.EmbedMultipleConfs(mol, numConfs=self.n_conformers,
-                                   randomSeed=42, numThreads=self.np,
-                                   pruneRmsThresh=self.threshold)
+        if self.n_conformers is None:
+            n_conformers = num_atoms - 1
+            AllChem.EmbedMultipleConfs(mol, numConfs=n_conformers,
+                                    randomSeed=42, numThreads=self.np,
+                                    pruneRmsThresh=self.threshold)
+        else:         
+            AllChem.EmbedMultipleConfs(mol, numConfs=self.n_conformers,
+                                    randomSeed=42, numThreads=self.np,
+                                    pruneRmsThresh=self.threshold)
         files = []
         for i in range(mol.GetNumConformers()):
             basename = name.strip() + f"_{i}.sdf"
@@ -168,6 +179,7 @@ class rd_isomer(object):
             writer.write(mol, confId=i)
             writer.close()
             files.append(file_path)
+        return len(files)
 
     def combine_SDF(self, SDFs, out):
         """Combine and sort SDF files in folder into a single file"""
@@ -219,6 +231,11 @@ class rd_isomer(object):
             self.conformer_func(smi_name)
 
         self.combine_SDF(self.rdk_tmp, self.enumerated_sdf)
+        try:
+            send2trash(self.rdk_tmp)
+        except:
+            shutil.rmtree(self.rdk_tmp)
+        return self.enumerated_sdf
 
 
 def oe_flipper(input, out):
